#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hunit
version:              0.10.2
visibility:           public
id:                   tasty-hunit-0.10.2-JTFiyouvuyFmzOhob5329
key:                  tasty-hunit-0.10.2-JTFiyouvuyFmzOhob5329
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  1d0a82fe45383a72e4a4fd4c9c481c65
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hunit-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.2-JTFiyouvuyFmzOhob5329
depends:
    base-4.18.2.1 call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    tasty-1.5.2-IM2bl9bLJtCFnmvQ3jLhCm

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

